@@ -88,7 +88,6 @@ class LightningModule(
             "automatic_optimization",
             "truncated_bptt_steps",
             "trainer",
-            "use_amp",  # from graveyard
         ]
         + _DeviceDtypeModuleMixin.__jit_unused_properties__
         + HyperparametersMixin.__jit_unused_properties__
@@ -117,6 +116,7 @@ class LightningModule(
         self._metric_attributes: Optional[Dict[int, str]] = None
         self._should_prevent_trainer_and_dataloaders_deepcopy: bool = False
         self._register_sharded_tensor_state_dict_hooks_if_available()
+        self._compiler_ctx: Optional[Dict[str, Any]] = None
 
     @overload
     def optimizers(self, use_pl_optimizer: Literal[True] = True) -> Union[LightningOptimizer, List[LightningOptimizer]]:
@@ -1947,6 +1947,70 @@ class LightningModule(
                 weakref.proxy(self), pre_load_state_dict_hook, True  # type: ignore[arg-type]
             )
 
+    @classmethod
+    def from_compiled(cls, model: "torch._dynamo.OptimizedModule") -> "pl.LightningModule":
+        """Returns an instance LightningModule from the output of ``torch.compile``.
+
+        The ``torch.compile`` function returns a ``torch._dynamo.OptimizedModule``, which wraps the LightningModule
+        passed in as an argument, but doesn't inherit from it. This means that the output of ``torch.compile`` behaves
+        like a LightningModule but it doesn't inherit from it (i.e. `isinstance` will fail).
+
+        Use this method to obtain a LightningModule that still runs with all the optimizations from ``torch.compile``.
+        """
+
+        from torch._dynamo import OptimizedModule
+
+        if not isinstance(model, OptimizedModule):
+            raise ValueError(
+                "`model` is required to be a `torch._dynamo.OptimizedModule`. " f"Found a `{type(model)}` instead."
+            )
+
+        orig_module = model._orig_mod
+
+        if not isinstance(orig_module, cls):
+            raise ValueError(
+                "`model` is expected to be a compiled LightingModule. " f"Found a compiled {type(orig_module)} instead"
+            )
+
+        orig_module._compiler_ctx = {
+            "compiler": "dynamo",
+            "dynamo_ctx": model.dynamo_ctx,
+            "original_forward": orig_module.forward,
+        }
+
+        orig_module.forward = model.dynamo_ctx(orig_module.forward)  # type: ignore[assignment]
+        return orig_module
+
+    @classmethod
+    def to_uncompiled(cls, model: Union["pl.LightningModule", "torch._dynamo.OptimizedModule"]) -> "pl.LightningModule":
+        """Returns an instance of LightningModule without any compilation optimizations from a compiled model.
+
+        This takes either a ``torch._dynamo.OptimizedModule`` returned by ``torch.compile()`` or a ``LightningModule``
+        returned by ``LightningModule.from_compiled``.
+
+        Note: this method will in-place modify the ``LightningModule`` that is passed in.
+        """
+
+        from torch._dynamo import OptimizedModule
+
+        if isinstance(model, OptimizedModule):
+            return model._orig_mod
+
+        elif isinstance(model, cls):
+            if model._compiler_ctx is None:
+                raise ValueError(
+                    "`model` is required to be a compiled LightningModule. "
+                    "Found a non-compiled LightningModule instead."
+                )
+
+        else:
+            raise ValueError("`model` must either be an instance of torch._dynamo.OptimizedModule or LightningModule")
+
+        model.forward = model._compiler_ctx["original_forward"]  # type: ignore[assignment]
+        model._compiler_ctx = None
+
+        return model
+
 
 @contextmanager
 def _jit_is_scripting() -> Generator:
