@@ -25,6 +25,7 @@ from warnings import warn
 
 import yaml
 from lightning_utilities.core.apply_func import apply_to_collection
+from typing_extensions import Self
 
 import pytorch_lightning as pl
 from lightning_lite.utilities.cloud_io import _load as pl_load
@@ -56,12 +57,12 @@ class ModelIO:
     @classmethod
     def load_from_checkpoint(
         cls,
-        checkpoint_path: Union[str, IO],
+        checkpoint_path: Union[_PATH, IO],
         map_location: _MAP_LOCATION_TYPE = None,
-        hparams_file: Optional[str] = None,
+        hparams_file: Optional[_PATH] = None,
         strict: bool = True,
         **kwargs: Any,
-    ) -> Union["pl.LightningModule", "pl.LightningDataModule"]:
+    ) -> Self:  # type: ignore[valid-type]
         r"""
         Primary way of loading a model from a checkpoint. When Lightning saves a checkpoint
         it stores the arguments passed to ``__init__``  in the checkpoint under ``"hyper_parameters"``.
