@@ -20,77 +20,32 @@ __all__ = [
 ]
 
 import logging
-import operator
 import os
-import warnings
 from argparse import Namespace
-from functools import reduce
-from typing import Any, Callable, Dict, Generator, Mapping, Optional, Sequence, Set, Union
-from weakref import ReferenceType
+from typing import Any, Dict, Generator, List, Optional, Set, Union
 
-import torch
+from lightning_utilities.core.imports import RequirementCache
 from torch import Tensor
 
-from pytorch_lightning import __version__
+import pytorch_lightning as pl
 from pytorch_lightning.callbacks import Checkpoint
 from pytorch_lightning.loggers.logger import Logger, rank_zero_experiment
-from pytorch_lightning.utilities.imports import _compare_version, _module_available
 from pytorch_lightning.utilities.logger import _add_prefix, _convert_params, _sanitize_callable_params
 from pytorch_lightning.utilities.model_summary import ModelSummary
 from pytorch_lightning.utilities.rank_zero import rank_zero_only
 
-# Note: Do not use RequirementCache. See: https://github.com/Lightning-AI/lightning/issues/14695
-_NEPTUNE_AVAILABLE = _module_available("neptune")
-_NEPTUNE_GREATER_EQUAL_0_9 = _compare_version("neptune", operator.ge, "0.9.0")
-
-
-if _NEPTUNE_AVAILABLE and _NEPTUNE_GREATER_EQUAL_0_9:
-    try:
-        from neptune import new as neptune
-        from neptune.new.exceptions import NeptuneLegacyProjectException, NeptuneOfflineModeFetchException
-        from neptune.new.run import Run
-        from neptune.new.types import File as NeptuneFile
-    except ModuleNotFoundError:
-        import neptune
-        from neptune.exceptions import NeptuneLegacyProjectException, NeptuneOfflineModeFetchException
-        from neptune.run import Run
-        from neptune.types import File as NeptuneFile
+_NEPTUNE_AVAILABLE = RequirementCache("neptune-client")
+if _NEPTUNE_AVAILABLE:
+    from neptune import new as neptune
+    from neptune.new.run import Run
 else:
     # needed for test mocks, and function signatures
-    neptune, Run, NeptuneFile = None, None, None
+    neptune, Run = None, None
 
 log = logging.getLogger(__name__)
 
 _INTEGRATION_VERSION_KEY = "source_code/integrations/pytorch-lightning"
 
-# kwargs used in previous NeptuneLogger version, now deprecated
-_LEGACY_NEPTUNE_INIT_KWARGS = [
-    "project_name",
-    "offline_mode",
-    "experiment_name",
-    "experiment_id",
-    "params",
-    "properties",
-    "upload_source_files",
-    "abort_callback",
-    "logger",
-    "upload_stdout",
-    "upload_stderr",
-    "send_hardware_metrics",
-    "run_monitoring_thread",
-    "handle_uncaught_exceptions",
-    "git_info",
-    "hostname",
-    "notebook_id",
-    "notebook_path",
-]
-
-# kwargs used in legacy NeptuneLogger from neptune-pytorch-lightning package
-_LEGACY_NEPTUNE_LOGGER_KWARGS = [
-    "base_namespace",
-    "close_after_fit",
-]
-
 
 class NeptuneLogger(Logger):
     r"""
@@ -196,6 +151,7 @@ class NeptuneLogger(Logger):
     You can also pass ``neptune_run_kwargs`` to specify the run in the greater detail, like ``tags`` or ``description``:
 
     .. testcode::
+        :skipif: not _NEPTUNE_AVAILABLE
 
         from pytorch_lightning import Trainer
         from pytorch_lightning.loggers import NeptuneLogger
@@ -252,9 +208,7 @@ class NeptuneLogger(Logger):
 
     Raises:
         ModuleNotFoundError:
-            If required Neptune package in version >=0.9 is not installed on the device.
-        TypeError:
-            If configured project has not been migrated to new structure yet.
+            If required Neptune package is not installed.
         ValueError:
             If argument passed to the logger's constructor is incorrect.
     """
@@ -272,19 +226,13 @@ class NeptuneLogger(Logger):
         run: Optional["Run"] = None,
         log_model_checkpoints: Optional[bool] = True,
         prefix: str = "training",
-        agg_key_funcs: Optional[Mapping[str, Callable[[Sequence[float]], float]]] = None,
-        agg_default_func: Optional[Callable[[Sequence[float]], float]] = None,
-        **neptune_run_kwargs,
+        **neptune_run_kwargs: Any,
     ):
+        if not _NEPTUNE_AVAILABLE:
+            raise ModuleNotFoundError(str(_NEPTUNE_AVAILABLE))
         # verify if user passed proper init arguments
         self._verify_input_arguments(api_key, project, name, run, neptune_run_kwargs)
-        if neptune is None:
-            raise ModuleNotFoundError(
-                "You want to use the `Neptune` logger which is not installed yet, install it with"
-                " `pip install neptune-client`."
-            )
-
-        super().__init__(agg_key_funcs=agg_key_funcs, agg_default_func=agg_default_func)
+        super().__init__()
         self._log_model_checkpoints = log_model_checkpoints
         self._prefix = prefix
         self._run_name = name
@@ -292,26 +240,28 @@ class NeptuneLogger(Logger):
         self._api_key = api_key
         self._run_instance = run
         self._neptune_run_kwargs = neptune_run_kwargs
-        self._run_short_id = None
+        self._run_short_id: Optional[str] = None
 
         if self._run_instance is not None:
             self._retrieve_run_data()
 
             # make sure that we've log integration version for outside `Run` instances
-            self._run_instance[_INTEGRATION_VERSION_KEY] = __version__
+            self._run_instance[_INTEGRATION_VERSION_KEY] = pl.__version__
 
-    def _retrieve_run_data(self):
-        try:
-            self._run_instance.wait()
+    def _retrieve_run_data(self) -> None:
+        assert self._run_instance is not None
+        self._run_instance.wait()
+
+        if self._run_instance.exists("sys/id"):
             self._run_short_id = self._run_instance["sys/id"].fetch()
             self._run_name = self._run_instance["sys/name"].fetch()
-        except NeptuneOfflineModeFetchException:
+        else:
             self._run_short_id = "OFFLINE"
             self._run_name = "offline-name"
 
     @property
-    def _neptune_init_args(self):
-        args = {}
+    def _neptune_init_args(self) -> Dict:
+        args: Dict = {}
         # Backward compatibility in case of previous version retrieval
         try:
             args = self._neptune_run_kwargs
@@ -336,7 +286,7 @@ class NeptuneLogger(Logger):
 
         return args
 
-    def _construct_path_with_prefix(self, *keys) -> str:
+    def _construct_path_with_prefix(self, *keys: str) -> str:
         """Return sequence of keys joined by `LOGGER_JOIN_CHAR`, started with `_prefix` if defined."""
         if self._prefix:
             return self.LOGGER_JOIN_CHAR.join([self._prefix, *keys])
@@ -349,61 +299,27 @@ class NeptuneLogger(Logger):
         name: Optional[str],
         run: Optional["Run"],
         neptune_run_kwargs: dict,
-    ):
-        legacy_kwargs_msg = (
-            "Following kwargs are deprecated: {legacy_kwargs}.\n"
-            "If you are looking for the Neptune logger using legacy Python API,"
-            " it's still available as part of neptune-contrib package:\n"
-            "  - https://docs-legacy.neptune.ai/integrations/pytorch_lightning.html\n"
-            "The NeptuneLogger was re-written to use the neptune.new Python API\n"
-            "  - https://neptune.ai/blog/neptune-new\n"
-            "  - https://docs.neptune.ai/integrations-and-supported-tools/model-training/pytorch-lightning\n"
-            "You should use arguments accepted by either NeptuneLogger.init() or neptune.init()"
-        )
-
-        # check if user used legacy kwargs expected in `NeptuneLegacyLogger`
-        used_legacy_kwargs = [
-            legacy_kwarg for legacy_kwarg in neptune_run_kwargs if legacy_kwarg in _LEGACY_NEPTUNE_INIT_KWARGS
-        ]
-        if used_legacy_kwargs:
-            raise ValueError(legacy_kwargs_msg.format(legacy_kwargs=used_legacy_kwargs))
-
-        # check if user used legacy kwargs expected in `NeptuneLogger` from neptune-pytorch-lightning package
-        used_legacy_neptune_kwargs = [
-            legacy_kwarg for legacy_kwarg in neptune_run_kwargs if legacy_kwarg in _LEGACY_NEPTUNE_LOGGER_KWARGS
-        ]
-        if used_legacy_neptune_kwargs:
-            raise ValueError(legacy_kwargs_msg.format(legacy_kwargs=used_legacy_neptune_kwargs))
-
-        # check if user passed new client `Run` object
+    ) -> None:
+        # check if user passed the client `Run` object
         if run is not None and not isinstance(run, Run):
-            raise ValueError(
-                "Run parameter expected to be of type `neptune.new.Run`.\n"
-                "If you are looking for the Neptune logger using legacy Python API,"
-                " it's still available as part of neptune-contrib package:\n"
-                "  - https://docs-legacy.neptune.ai/integrations/pytorch_lightning.html\n"
-                "The NeptuneLogger was re-written to use the neptune.new Python API\n"
-                "  - https://neptune.ai/blog/neptune-new\n"
-                "  - https://docs.neptune.ai/integrations-and-supported-tools/model-training/pytorch-lightning\n"
-            )
-
-        # check if user passed redundant neptune.init arguments when passed run
+            raise ValueError("Run parameter expected to be of type `neptune.new.Run`.")
+        # check if user passed redundant neptune.init_run arguments when passed run
         any_neptune_init_arg_passed = any(arg is not None for arg in [api_key, project, name]) or neptune_run_kwargs
         if run is not None and any_neptune_init_arg_passed:
             raise ValueError(
                 "When an already initialized run object is provided"
-                " you can't provide other neptune.init() parameters.\n"
+                " you can't provide other neptune.init_run() parameters.\n"
             )
 
-    def __getstate__(self):
+    def __getstate__(self) -> Dict[str, Any]:
         state = self.__dict__.copy()
         # Run instance can't be pickled
         state["_run_instance"] = None
         return state
 
-    def __setstate__(self, state):
+    def __setstate__(self, state: Dict[str, Any]) -> None:
         self.__dict__ = state
-        self._run_instance = neptune.init(**self._neptune_init_args)
+        self._run_instance = neptune.init_run(**self._neptune_init_args)
 
     @property
     @rank_zero_experiment
@@ -438,21 +354,13 @@ class NeptuneLogger(Logger):
     @property
     @rank_zero_experiment
     def run(self) -> Run:
-        try:
-            if not self._run_instance:
-                self._run_instance = neptune.init(**self._neptune_init_args)
-                self._retrieve_run_data()
-                # make sure that we've log integration version for newly created
-                self._run_instance[_INTEGRATION_VERSION_KEY] = __version__
+        if not self._run_instance:
+            self._run_instance = neptune.init_run(**self._neptune_init_args)
+            self._retrieve_run_data()
+            # make sure that we've log integration version for newly created
+            self._run_instance[_INTEGRATION_VERSION_KEY] = pl.__version__
 
-            return self._run_instance
-        except NeptuneLegacyProjectException as e:
-            raise TypeError(
-                f"Project {self._project_name} has not been migrated to the new structure."
-                " You can still integrate it with the Neptune logger using legacy Python API"
-                " available as part of neptune-contrib package:"
-                " https://docs-legacy.neptune.ai/integrations/pytorch_lightning.html\n"
-            ) from e
+        return self._run_instance
 
     @rank_zero_only
     def log_hyperparams(self, params: Union[Dict[str, Any], Namespace]) -> None:  # skipcq: PYL-W0221
@@ -517,6 +425,10 @@ class NeptuneLogger(Logger):
 
     @rank_zero_only
     def finalize(self, status: str) -> None:
+        if not self._run_instance:
+            # When using multiprocessing, finalize() should be a no-op on the main process, as no experiment has been
+            # initialized there
+            return
         if status:
             self.run[self._construct_path_with_prefix("status")] = status
 
@@ -533,14 +445,14 @@ class NeptuneLogger(Logger):
         return os.path.join(os.getcwd(), ".neptune")
 
     @rank_zero_only
-    def log_model_summary(self, model, max_depth=-1):
+    def log_model_summary(self, model: "pl.LightningModule", max_depth: int = -1) -> None:
         model_str = str(ModelSummary(model=model, max_depth=max_depth))
         self.run[self._construct_path_with_prefix("model/summary")] = neptune.types.File.from_content(
             content=model_str, extension="txt"
         )
 
     @rank_zero_only
-    def after_save_checkpoint(self, checkpoint_callback: "ReferenceType[Checkpoint]") -> None:
+    def after_save_checkpoint(self, checkpoint_callback: Checkpoint) -> None:
         """Automatically log checkpointed model. Called after model checkpoint callback saves a new checkpoint.
 
         Args:
@@ -588,7 +500,7 @@ class NeptuneLogger(Logger):
             )
 
     @staticmethod
-    def _get_full_model_name(model_path: str, checkpoint_callback: "ReferenceType[Checkpoint]") -> str:
+    def _get_full_model_name(model_path: str, checkpoint_callback: Checkpoint) -> str:
         """Returns model name which is string `model_path` appended to `checkpoint_callback.dirpath`."""
         if hasattr(checkpoint_callback, "dirpath"):
             expected_model_path = f"{checkpoint_callback.dirpath}{os.path.sep}"
@@ -602,14 +514,16 @@ class NeptuneLogger(Logger):
         return filepath
 
     @classmethod
-    def _get_full_model_names_from_exp_structure(cls, exp_structure: dict, namespace: str) -> Set[str]:
+    def _get_full_model_names_from_exp_structure(cls, exp_structure: Dict[str, Any], namespace: str) -> Set[str]:
         """Returns all paths to properties which were already logged in `namespace`"""
-        structure_keys = namespace.split(cls.LOGGER_JOIN_CHAR)
-        uploaded_models_dict = reduce(lambda d, k: d[k], [exp_structure, *structure_keys])
+        structure_keys: List[str] = namespace.split(cls.LOGGER_JOIN_CHAR)
+        for key in structure_keys:
+            exp_structure = exp_structure[key]
+        uploaded_models_dict = exp_structure
         return set(cls._dict_paths(uploaded_models_dict))
 
     @classmethod
-    def _dict_paths(cls, d: dict, path_in_build: str = None) -> Generator:
+    def _dict_paths(cls, d: Dict[str, Any], path_in_build: str = None) -> Generator:
         for k, v in d.items():
             path = f"{path_in_build}/{k}" if path_in_build is not None else k
             if not isinstance(v, dict):
@@ -618,74 +532,14 @@ class NeptuneLogger(Logger):
                 yield from cls._dict_paths(v, path)
 
     @property
-    def name(self) -> str:
+    def name(self) -> Optional[str]:
         """Return the experiment name or 'offline-name' when exp is run in offline mode."""
         return self._run_name
 
     @property
-    def version(self) -> str:
+    def version(self) -> Optional[str]:
         """Return the experiment version.
 
         It's Neptune Run's short_id
         """
         return self._run_short_id
-
-    @staticmethod
-    def _signal_deprecated_api_usage(f_name, sample_code, raise_exception=False):
-        msg_suffix = (
-            f"If you are looking for the Neptune logger using legacy Python API,"
-            f" it's still available as part of neptune-contrib package:\n"
-            f"  - https://docs-legacy.neptune.ai/integrations/pytorch_lightning.html\n"
-            f"The NeptuneLogger was re-written to use the neptune.new Python API\n"
-            f"  - https://neptune.ai/blog/neptune-new\n"
-            f"  - https://docs.neptune.ai/integrations-and-supported-tools/model-training/pytorch-lightning\n"
-            f"Instead of `logger.{f_name}` you can use:\n"
-            f"\t{sample_code}"
-        )
-
-        if not raise_exception:
-            warnings.warn(
-                "The function you've used is deprecated in v1.5.0 and will be removed in v1.7.0. " + msg_suffix
-            )
-        else:
-            raise ValueError("The function you've used is deprecated.\n" + msg_suffix)
-
-    @rank_zero_only
-    def log_metric(self, metric_name: str, metric_value: Union[Tensor, float, str], step: Optional[int] = None):
-        key = f"{self._prefix}/{metric_name}"
-        self._signal_deprecated_api_usage("log_metric", f"logger.run['{key}'].log(42)")
-        if torch.is_tensor(metric_value):
-            metric_value = metric_value.cpu().detach()
-
-        self.run[key].log(metric_value, step=step)
-
-    @rank_zero_only
-    def log_text(self, log_name: str, text: str, step: Optional[int] = None) -> None:
-        key = f"{self._prefix}/{log_name}"
-        self._signal_deprecated_api_usage("log_text", f"logger.run['{key}].log('text')")
-        self.run[key].log(str(text), step=step)
-
-    @rank_zero_only
-    def log_image(self, log_name: str, image: Union[str, Any], step: Optional[int] = None) -> None:
-        key = f"{self._prefix}/{log_name}"
-        self._signal_deprecated_api_usage("log_image", f"logger.run['{key}'].log(File('path_to_image'))")
-        if isinstance(image, str):
-            # if `img` is path to file, convert it to file object
-            image = NeptuneFile(image)
-        self.run[key].log(image, step=step)
-
-    @rank_zero_only
-    def log_artifact(self, artifact: str, destination: Optional[str] = None) -> None:
-        key = f"{self._prefix}/{self.ARTIFACTS_KEY}/{artifact}"
-        self._signal_deprecated_api_usage("log_artifact", f"logger.run['{key}].log('path_to_file')")
-        self.run[key].log(destination)
-
-    def set_property(self, *args, **kwargs):
-        self._signal_deprecated_api_usage(
-            "log_artifact", f"logger.run['{self._prefix}/{self.PARAMETERS_KEY}/key'].log(value)", raise_exception=True
-        )
-
-    def append_tags(self, *args, **kwargs):
-        self._signal_deprecated_api_usage(
-            "append_tags", "logger.run['sys/tags'].add(['foo', 'bar'])", raise_exception=True
-        )
