@@ -17,9 +17,8 @@ import copy
 import inspect
 import pickle
 import types
-from argparse import Namespace
 from dataclasses import fields, is_dataclass
-from typing import Any, Dict, List, Optional, Sequence, Tuple, Type, Union
+from typing import Any, Dict, List, MutableMapping, Optional, Sequence, Tuple, Type, Union
 
 from torch import nn
 from typing_extensions import Literal
@@ -94,21 +93,18 @@ def is_picklable(obj: object) -> bool:
         return False
 
 
-def clean_namespace(hparams: Union[Dict[str, Any], Namespace]) -> None:
+def clean_namespace(hparams: MutableMapping) -> None:
     """Removes all unpicklable entries from hparams."""
-
-    hparams_dict = hparams
-    if isinstance(hparams, Namespace):
-        hparams_dict = hparams.__dict__
-
-    del_attrs = [k for k, v in hparams_dict.items() if not is_picklable(v)]
+    del_attrs = [k for k, v in hparams.items() if not is_picklable(v)]
 
     for k in del_attrs:
         rank_zero_warn(f"attribute '{k}' removed from hparams because it cannot be pickled")
-        del hparams_dict[k]
+        del hparams[k]
 
 
-def parse_class_init_keys(cls: Type["pl.LightningModule"]) -> Tuple[str, Optional[str], Optional[str]]:
+def parse_class_init_keys(
+    cls: Union[Type["pl.LightningModule"], Type["pl.LightningDataModule"]]
+) -> Tuple[str, Optional[str], Optional[str]]:
     """Parse key words for standard ``self``, ``*args`` and ``**kwargs``.
 
     Examples:
@@ -260,8 +256,6 @@ def save_hyperparameters(
 
     # `hparams` are expected here
     obj._set_hparams(hp)
-    # make deep copy so there is not other runtime changes reflected
-    obj._hparams_initial = copy.deepcopy(obj._hparams)
 
     for k, v in obj._hparams.items():
         if isinstance(v, nn.Module):
@@ -270,6 +264,9 @@ def save_hyperparameters(
                 f" It is recommended to ignore them using `self.save_hyperparameters(ignore=[{k!r}])`."
             )
 
+    # make a deep copy so there are no other runtime changes reflected
+    obj._hparams_initial = copy.deepcopy(obj._hparams)
+
 
 class AttributeDict(Dict):
     """Extended dictionary accessible with dot notation.
